require 'active_support'
require 'active_support/core_ext/hash/reverse_merge'
require 'active_model'

class JsonValidator < ActiveModel::EachValidator
  def initialize(options)
    options.reverse_merge!(message: :invalid_json)
    super
  end

  def validate_each(record, attribute, value)
    return if json?(value)
    message = options.fetch(:message)

    record.errors.add(attribute, message)
  end

  private

  def json?(str)
    return false unless str.is_a?(String)
    JSON.parse(str).all?
  rescue JSON::ParserError
    false
  end
end
